@@ -78,7 +78,7 @@ M2A = function(data, BadStart, nchains, method, niter){
     # Run optimization
     m2a.out = list()
     for (i in 1:nchains){
-        chain.out = suppressWarnings(stats::optim(c(q1[i], k1[i]), fn = m2a, method = method, control = list(maxit = niter)))
+        chain.out = suppressWarnings(stats::optim(c(q1[i], k1[i]), fn = m2a, method = method, control = list(maxit = niter), hessian = T))
         names(chain.out)[2] = "lik"
         m2a.out[[i]] = chain.out
     }
